@@ -90,3 +90,16 @@ test_that("Bulk download online", {
     )
   )
 })
+
+test_that("Bulk download offline", {
+  options(giscoR_test_offline = TRUE)
+  expect_message(
+    n <- gisco_bulk_download(
+      resolution = 60, cache_dir = tempdir(),
+      update_cache = TRUE
+    ),
+    "not reachable"
+  )
+  expect_null(n)
+  options(giscoR_test_offline = FALSE)
+})
